@@ -15,11 +15,13 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from __future__ import print_function
+import atexit
 import codecs
 from debian.deb822 import Deb822
 import glob
 import inspect
 import json
+import logging
 import magic
 import os
 import pprint
@@ -35,9 +37,6 @@ DEBUGGING = False
 UNPACK_DIR = None
 RAW_UNPACK_DIR = None
 
-# cleanup
-import atexit
-
 
 def cleanup_unpack():
     global UNPACK_DIR
@@ -67,6 +66,7 @@ class ClickReview(object):
     # click service)
     app_allowed_peer_hooks = ["account-application",
                               "account-service",
+                              "accounts",
                               "account-provider",
                               "account-qml-plugin",
                               "apparmor",
@@ -77,6 +77,7 @@ class ClickReview(object):
                               ]
     scope_allowed_peer_hooks = ["account-application",
                                 "account-service",
+                                "accounts",
                                 "apparmor",
                                 "scope",
                                 ]
@@ -106,7 +107,8 @@ class ClickReview(object):
                            "security-override",
                            "security-policy"]
 
-    def __init__(self, fn, review_type, peer_hooks=None, overrides=None):
+    def __init__(self, fn, review_type, peer_hooks=None, overrides=None,
+                 peer_hooks_link=None):
         self.click_package = fn
         self._check_path_exists()
         if not self.click_package.endswith(".click") and \
@@ -190,6 +192,7 @@ class ClickReview(object):
 
         self.peer_hooks = peer_hooks
         self.overrides = overrides if overrides is not None else {}
+        self.peer_hooks_link = peer_hooks_link
 
     def _extract_click_frameworks(self):
         '''Extract installed click frameworks'''
@@ -461,7 +464,7 @@ class ClickReview(object):
                 continue
             d = self._verify_peer_hooks(hook)
             t = 'info'
-            n = "peer_hooks_required_%s" % hook
+            n = self._get_check_name("peer_hooks_required", extra=hook)
             s = "OK"
 
             if 'missing' in d and len(d['missing'].keys()) > 0:
@@ -469,12 +472,13 @@ class ClickReview(object):
                 for app in d['missing']:
                     s = "Missing required hooks for '%s': %s" % (
                         app, ", ".join(d['missing'][app]))
-                    self._add_result(t, n, s, manual_review=True)
+                    self._add_result(t, n, s, manual_review=True,
+                                     link=self.peer_hooks_link)
             else:
                 self._add_result(t, n, s)
 
             t = 'info'
-            n = "peer_hooks_disallowed_with_%s" % hook
+            n = self._get_check_name("peer_hooks_disallowed", extra=hook)
             s = "OK"
 
             if 'disallowed' in d and len(d['disallowed'].keys()) > 0:
@@ -482,7 +486,8 @@ class ClickReview(object):
                 for app in d['disallowed']:
                     s = "Disallowed with %s (%s): %s" % (
                         hook, app, ", ".join(d['disallowed'][app]))
-                    self._add_result(t, n, s, manual_review=True)
+                    self._add_result(t, n, s, manual_review=True,
+                                     link=self.peer_hooks_link)
             else:
                 self._add_result(t, n, s)
 
@@ -490,6 +495,14 @@ class ClickReview(object):
         '''Set review name'''
         self.review_type = name
 
+    def _get_check_name(self, name, app='', extra=''):
+        name = ':'.join([self.review_type, name])
+        if app:
+            name += ':' + app
+        if extra:
+            name += ':' + extra
+        return name
+
     # click_report[<result_type>][<review_name>] = <result>
     #   result_type: info, warn, error
     #   review_name: name of the check (prefixed with self.review_type)
@@ -500,16 +513,23 @@ class ClickReview(object):
         if result_type not in self.result_types:
             error("Invalid result type '%s'" % result_type)
 
-        name = "%s_%s" % (self.review_type, review_name)
-        if name not in self.click_report[result_type]:
-            self.click_report[result_type][name] = dict()
+        if review_name not in self.click_report[result_type]:
+            # log info about check so it can be collected into the
+            # check-names.list file
+            # format should be
+            # CHECK|<review_type:check_name>|<link>
+            msg = 'CHECK|{}|{}'
+            name = ':'.join(review_name.split(':')[:2])
+            link_text = link if link is not None else ""
+            logging.debug(msg.format(name, link_text))
+            self.click_report[result_type][review_name] = dict()
 
-        self.click_report[result_type][name].update({
+        self.click_report[result_type][review_name].update({
             'text': result,
             'manual_review': manual_review,
         })
         if link is not None:
-            self.click_report[result_type][name]["link"] = link
+            self.click_report[result_type][review_name]["link"] = link
 
     def do_report(self):
         '''Print report'''
